'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var axios = _interopDefault(require('axios'));

// A type of promise-like that resolves synchronously and supports only one observer

const _iteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator"))) : "@@iterator";

const _asyncIteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.asyncIterator || (Symbol.asyncIterator = Symbol("Symbol.asyncIterator"))) : "@@asyncIterator";

// Asynchronously call a function and send errors to recovery continuation
function _catch(body, recover) {
	try {
		var result = body();
	} catch(e) {
		return recover(e);
	}
	if (result && result.then) {
		return result.then(void 0, recover);
	}
	return result;
}

var getUsernameFromGistUrl = function getUsernameFromGistUrl(userName) {
  return Promise.resolve("https://api.github.com/users/" + userName);
}; //   gistUrl = String(gistUrl);

function GitUserInfo(_ref) {
  var gistUsername = _ref.gistUsername;
  var _useState = React.useState(null),
    userInfo = _useState[0],
    setUserInfo = _useState[1];
  React.useEffect(function () {
    var fetchUserInfo = function fetchUserInfo() {
      try {
        var _temp = _catch(function () {
          var _get = axios.get;
          return Promise.resolve(getUsernameFromGistUrl(gistUsername)).then(function (_getUsernameFromGistU) {
            return Promise.resolve(_get.call(axios, _getUsernameFromGistU)).then(function (response) {
              var _response$data = response.data,
                avatar_url = _response$data.avatar_url,
                name = _response$data.name;
              setUserInfo({
                avatarUrl: avatar_url,
                name: name
              });
            });
          });
        }, function (error) {
          console.error('Error fetching user information:', error);
        });
        return Promise.resolve(_temp && _temp.then ? _temp.then(function () {}) : void 0);
      } catch (e) {
        return Promise.reject(e);
      }
    };
    fetchUserInfo();
  }, [gistUsername]); // <-- Include gistUsername in dependency array
  return React__default.createElement("div", null, userInfo ? React__default.createElement("div", {
    style: {
      display: 'flex',
      alignItems: 'center'
    }
  }, React__default.createElement("img", {
    src: userInfo.avatarUrl,
    alt: "Avatar",
    style: {
      width: 30,
      height: 30,
      borderRadius: '50%'
    }
  }), React__default.createElement("p", {
    style: {
      padding: '5px'
    }
  }, "Gist By. ", userInfo.name)) : React__default.createElement("div", null));
}

var CreateIframe = function CreateIframe(_ref) {
  var iframeRef = _ref.iframeRef,
    width = _ref.width,
    height = _ref.height,
    file = _ref.file,
    id = _ref.id;
  return React__default.createElement("iframe", {
    ref: iframeRef,
    width: width,
    height: height,
    src: file,
    id: id
  });
};

function createGitGistUrl(id, file) {
  var baseUrl = 'https://gist.github.com/';
  var fileArg = file ? "?file=" + file : '';
  return "" + baseUrl + id + ".js" + fileArg;
}
function GitGist(_ref) {
  var id = _ref.id,
    file = _ref.file,
    _ref$width = _ref.width,
    width = _ref$width === void 0 ? '100%' : _ref$width,
    _ref$height = _ref.height,
    height = _ref$height === void 0 ? '600px' : _ref$height,
    _ref$getProfile = _ref.getProfile,
    getProfile = _ref$getProfile === void 0 ? 'false' : _ref$getProfile,
    _ref$userName = _ref.userName,
    userName = _ref$userName === void 0 ? "" : _ref$userName;
  var iframeRef = React.useRef(null);
  var _useState = React.useState(''),
    gistLink = _useState[0],
    setGistLink = _useState[1];
  React.useEffect(function () {
    var link = createGitGistUrl(id, file);
    setGistLink(link);
  }, [id, file]);
  React.useEffect(function () {
    console.log(userName);
    function updateIframeContent() {
      var _iframe$contentWindow;
      var iframe = iframeRef.current;
      if (!iframe) return;
      var doc = (_iframe$contentWindow = iframe.contentWindow) === null || _iframe$contentWindow === void 0 ? void 0 : _iframe$contentWindow.document;
      if (!doc) return;
      var html = "<script type=\"text/javascript\" src=\"" + gistLink + "\"></script>";
      doc.open();
      doc.write(html);
      doc.close();
    }
    updateIframeContent();
  }, [gistLink]);
  return React__default.createElement("div", null, getProfile == 'true' && React__default.createElement(GitUserInfo, {
    gistUsername: userName
  }), React__default.createElement(CreateIframe, {
    iframeRef: iframeRef,
    width: width,
    height: height,
    file: file,
    id: id
  }));
}

exports.default = GitGist;
//# sourceMappingURL=react-nextjs-github-gist.cjs.development.js.map
